@@ -1,58 +1,25 @@
-#=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
-#
-#=======================================================================
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2 of the License, or (at your option) any later version.
-#
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the
-#   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-#   Boston, MA 02111-1307, USA.
-#
-#   $Id: Annotation.pm,v 2.1 2007/10/02 19:59:37 areibens Exp $
-#
-#=======================================================================
 package PDF::API2::Annotation;
 
-BEGIN 
-{
+our $VERSION = '2.016';
 
-    use strict;
-    use vars qw(@ISA $VERSION);
+use base 'PDF::API2::Basic::PDF::Dict';
 
-    use PDF::API2::Basic::PDF::Dict;
-    use PDF::API2::Basic::PDF::Utils;
-    use PDF::API2::Util;
+use Encode qw(:all);
 
-    @ISA = qw(PDF::API2::Basic::PDF::Dict);
-
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/10/02 19:59:37 $
-
-    use utf8;
-    use Encode qw(:all);
-}
+use PDF::API2::Basic::PDF::Utils;
+use PDF::API2::Util;
 
 no warnings qw[ deprecated recursion uninitialized ];
 
-=head1 $ant = PDF::API2::Annotation->new
+=head1 NAME
+
+PDF::API2::Annotation
+
+=head1 METHODS
+
+=over
+
+=item $ant = PDF::API2::Annotation->new
 
 Returns a annotation object (called from $page->annotation).
 
@@ -424,81 +391,10 @@ sub dest
 
 __END__
 
+=back
+
 =head1 AUTHOR
 
-alfred reibenschuh
-
-=head1 HISTORY
-
-    $Log: Annotation.pm,v $
-    Revision 2.1  2007/10/02 19:59:37  areibens
-    added movie annotation
-
-    Revision 2.0  2005/11/16 02:16:00  areibens
-    revision workaround for SF cvs import not to screw up CPAN
-
-    Revision 1.2  2005/11/16 01:27:48  areibens
-    genesis2
-
-    Revision 1.1  2005/11/16 01:19:24  areibens
-    genesis
-
-    Revision 1.21  2005/06/17 19:43:46  fredo
-    fixed CPAN modulefile versioning (again)
-
-    Revision 1.20  2005/06/17 18:53:04  fredo
-    fixed CPAN modulefile versioning (dislikes cvs)
-
-    Revision 1.19  2005/06/14 12:55:59  fredo
-    fixed typo for text annotation leaving it empty
-
-    Revision 1.18  2005/03/14 22:01:05  fredo
-    upd 2005
-
-    Revision 1.17  2005/01/03 05:00:27  fredo
-    changed default behavior of border
-
-    Revision 1.16  2005/01/03 04:17:24  fredo
-    fixed link bug
-
-    Revision 1.15  2005/01/03 03:29:31  fredo
-    removed code duplication
-
-    Revision 1.14  2005/01/03 00:30:31  fredo
-    added named destination support
-
-    Revision 1.13  2004/12/16 00:30:51  fredo
-    added no warn for recursion
-
-    Revision 1.12  2004/10/13 18:30:34  fredo
-    fixed pdfile method from utf8 back to ascii
-
-    Revision 1.11  2004/10/11 07:54:24  fredo
-    fixed file method from utf8 back to ascii
-
-    Revision 1.10  2004/10/01 01:20:35  fredo
-    fixed url link annotation to 7-bit ascii as per pdf-spec-1.5
-
-    Revision 1.9  2004/06/15 09:11:37  fredo
-    removed cr+lf
-
-    Revision 1.8  2004/06/07 19:43:58  fredo
-    cleaned out cr+lf for lf
-
-    Revision 1.7  2004/02/22 23:55:49  fredo
-    full utf8 awareness
-
-    Revision 1.6  2004/02/05 13:33:18  fredo
-    added unicode handling to strings
-
-    Revision 1.5  2003/12/08 13:05:18  Administrator
-    corrected to proper licencing statement
-
-    Revision 1.4  2003/12/08 11:55:17  Administrator
-    change for proper module versioning
-
-    Revision 1.3  2003/11/30 17:08:11  Administrator
-    merged into default
-
+Alfred Reibenschuh
 
 =cut
