@@ -1,18 +1,7 @@
 #=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#=======================================================================
 #
 #   THIS IS A REUSED PERL MODULE, FOR PROPER LICENCING TERMS SEE BELOW:
 #
-#
 #   Copyright Martin Hosken <Martin_Hosken@sil.org>
 #
 #   No warranty or expression of effectiveness, least of all regarding
@@ -20,37 +9,30 @@
 #
 #   This specific module is licensed under the Perl Artistic License.
 #
-#
-#   $Id: Number.pm,v 1.6 2004/12/16 00:30:52 fredo Exp $
-#
 #=======================================================================
 package PDF::API2::Basic::PDF::Number;
 
+our $VERSION = '2.016';
+
+use base 'PDF::API2::Basic::PDF::String';
+
+use strict;
+
 =head1 NAME
 
 PDF::API2::Basic::PDF::Number - Numbers in PDF. Inherits from L<PDF::API2::Basic::PDF::String>
 
 =head1 METHODS
 
-=cut
-
-use strict;
-use vars qw(@ISA);
-no warnings qw[ deprecated recursion uninitialized ];
-
-use PDF::API2::Basic::PDF::String;
-@ISA = qw(PDF::API2::Basic::PDF::String);
-
-
 =head2 $n->convert($str)
 
 Converts a string from PDF to internal, by doing nothing
 
 =cut
 
-sub convert
-{ return $_[1]; }
-
+sub convert {
+    return $_[1];
+}
 
 =head2 $n->as_pdf
 
@@ -58,13 +40,14 @@ Converts a number to PDF format
 
 =cut
 
-sub as_pdf
-{ $_[0]->{'val'}; }
-
-sub outxmldeep
-{
-    my ($self, $fh, $pdf, %opts) = @_;
-
-    $opts{-xmlfh}->print("<Number>".$self->val."</Number>\n");
+sub as_pdf {
+    return $_[0]->{'val'};
 }
 
+sub outxmldeep {
+    my ($self, $fh, $pdf, %opts) = @_;
+
+    $opts{'-xmlfh'}->print('<Number>' . $self->val() . "</Number>\n");
+}
+
+1;
