@@ -1,18 +1,7 @@
 #=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#=======================================================================
 #
 #   THIS IS A REUSED PERL MODULE, FOR PROPER LICENCING TERMS SEE BELOW:
 #
-#
 #   Copyright Martin Hosken <Martin_Hosken@sil.org>
 #
 #   No warranty or expression of effectiveness, least of all regarding
@@ -20,12 +9,11 @@
 #
 #   This specific module is licensed under the Perl Artistic License.
 #
-#
-#   $Id: Utils.pm,v 2.0 2005/11/16 02:16:00 areibens Exp $
-#
 #=======================================================================
 package PDF::API2::Basic::PDF::Utils;
 
+our $VERSION = '2.016';
+
 =head1 NAME
 
 PDF::API2::Basic::PDF::Utils - Utility functions for PDF library
@@ -52,10 +40,9 @@ use PDF::API2::Basic::PDF::Literal;
 use Exporter;
 use vars qw(@EXPORT @ISA);
 @ISA = qw(Exporter);
-@EXPORT = qw(PDFBool PDFArray PDFDict PDFLiteral PDFName PDFNull PDFNum PDFStr PDFStrHex PDFUtf
-             asPDFBool asPDFName asPDFNum asPDFStr);
-no warnings qw[ deprecated recursion uninitialized ];
-
+@EXPORT = qw(PDFBool PDFArray PDFDict PDFLiteral PDFName PDFNull
+             PDFNum PDFStr PDFStrHex PDFUtf asPDFBool asPDFName
+             asPDFNum asPDFStr);
 
 =head2 PDFBool
 
@@ -63,9 +50,9 @@ Creates a Bool via PDF::API2::Basic::PDF::Bool->new
 
 =cut
 
-sub PDFBool
-{ PDF::API2::Basic::PDF::Bool->new(@_); }
-
+sub PDFBool {
+    return PDF::API2::Basic::PDF::Bool->new(@_);
+}
 
 =head2 PDFArray
 
@@ -73,9 +60,9 @@ Creates an array via PDF::API2::Basic::PDF::Array->new
 
 =cut
 
-sub PDFArray
-{ PDF::API2::Basic::PDF::Array->new(@_); }
-
+sub PDFArray {
+    return PDF::API2::Basic::PDF::Array->new(@_);
+}
 
 =head2 PDFDict
 
@@ -83,9 +70,9 @@ Creates a dict via PDF::API2::Basic::PDF::Dict->new
 
 =cut
 
-sub PDFDict
-{ PDF::API2::Basic::PDF::Dict->new(@_); }
-
+sub PDFDict {
+    return PDF::API2::Basic::PDF::Dict->new(@_);
+}
 
 =head2 PDFName
 
@@ -93,9 +80,9 @@ Creates a name via PDF::API2::Basic::PDF::Name->new
 
 =cut
 
-sub PDFName
-{ PDF::API2::Basic::PDF::Name->new(@_); }
-
+sub PDFName {
+    return PDF::API2::Basic::PDF::Name->new(@_);
+}
 
 =head2 PDFNull
 
@@ -103,9 +90,9 @@ Creates a null via PDF::API2::Basic::PDF::Null->new
 
 =cut
 
-sub PDFNull
-{ PDF::API2::Basic::PDF::Null->new(@_); }
-
+sub PDFNull {
+    return PDF::API2::Basic::PDF::Null->new(@_);
+}
 
 =head2 PDFNum
 
@@ -113,9 +100,9 @@ Creates a number via PDF::API2::Basic::PDF::Number->new
 
 =cut
 
-sub PDFNum
-{ PDF::API2::Basic::PDF::Number->new(@_); }
-
+sub PDFNum {
+    return PDF::API2::Basic::PDF::Number->new(@_);
+}
 
 =head2 PDFStr
 
@@ -123,8 +110,9 @@ Creates a string via PDF::API2::Basic::PDF::String->new
 
 =cut
 
-sub PDFStr
-{ PDF::API2::Basic::PDF::String->new(@_); }
+sub PDFStr {
+    return PDF::API2::Basic::PDF::String->new(@_);
+}
 
 =head2 PDFStrHex
 
@@ -132,8 +120,11 @@ Creates a hex-string via PDF::API2::Basic::PDF::String->new
 
 =cut
 
-sub PDFStrHex
-{ my $x=PDF::API2::Basic::PDF::String->new(@_); $x->{' ishex'}=1; return($x); }
+sub PDFStrHex {
+    my $string = PDF::API2::Basic::PDF::String->new(@_);
+    $string->{' ishex'} = 1;
+    return $string;
+}
 
 =head2 PDFUtf
 
@@ -141,8 +132,11 @@ Creates a utf8-string via PDF::API2::Basic::PDF::String->new
 
 =cut
 
-sub PDFUtf
-{ my $x=PDF::API2::Basic::PDF::String->new(@_); $x->{' isutf'}=1; return($x); }
+sub PDFUtf {
+    my $string = PDF::API2::Basic::PDF::String->new(@_);
+    $string->{' isutf'} = 1;
+    return $string;
+}
 
 =head2 PDFLiteral
 
@@ -150,8 +144,9 @@ Creates a pdf-literal via PDF::API2::Basic::PDF::Literal->new
 
 =cut
 
-sub PDFLiteral
-{ PDF::API2::Basic::PDF::Literal->new(@_); }
+sub PDFLiteral {
+    return PDF::API2::Basic::PDF::Literal->new(@_);
+}
 
 =head2 asPDFBool
 
@@ -159,9 +154,9 @@ Returns a literal value in PDF output form
 
 =cut
 
-sub asPDFBool
-{ PDF::API2::Basic::PDF::Bool->new(@_)->as_pdf; }
-
+sub asPDFBool {
+    return PDF::API2::Basic::PDF::Bool->new(@_)->as_pdf();
+}
 
 =head2 asPDFStr
 
@@ -169,9 +164,9 @@ Returns a string in PDF output form (including () or <>)
 
 =cut
 
-sub asPDFStr
-{ PDF::API2::Basic::PDF::String->new(@_)->as_pdf; }
-
+sub asPDFStr {
+    return PDF::API2::Basic::PDF::String->new(@_)->as_pdf();
+}
 
 =head2 asPDFName
 
@@ -179,9 +174,9 @@ Returns a Name in PDF Output form (including /)
 
 =cut
 
-sub asPDFName
-{ PDF::API2::Basic::PDF::Name->new(@_)->as_pdf (@_); }
-
+sub asPDFName {
+    return PDF::API2::Basic::PDF::Name->new(@_)->as_pdf();
+}
 
 =head2 asPDFNum
 
@@ -189,24 +184,9 @@ Returns a number in PDF output form
 
 =cut
 
-sub asPDFNum
-{ $_[0]; }          # no translation needed
-
-
-=head2 unpacku($str)
-
-Returns a list of unicode values for the given UTF8 string
-
-=cut
-
-sub unpacku
-{
-    my ($str) = @_;
-    my (@res);
-
-    return (unpack("U*", $str));
+sub asPDFNum {
+    # no translation needed
+    return $_[0];
 }
 
-
 1;
-
