@@ -1,38 +1,7 @@
-#=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
-#
-#=======================================================================
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2 of the License, or (at your option) any later version.
-#
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the
-#   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-#   Boston, MA 02111-1307, USA.
-#
-#   $Id: Lite.pm,v 2.1 2007/05/08 18:32:09 areibens Exp $
-#
-#=======================================================================
-
 package PDF::API2::Lite;
 
+our $VERSION = '2.016';
+
 BEGIN {
 
     use PDF::API2;
@@ -41,15 +10,12 @@ BEGIN {
 
     use POSIX qw( ceil floor );
 
-    use vars qw( $VERSION $hasWeakRef );
-
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/05/08 18:32:09 $
+    use vars qw( $hasWeakRef );
 
 }
 
 no warnings qw[ deprecated recursion uninitialized ];
 
-
 =head1 NAME 
 
 PDF::API2::Lite - lite pdf creation
@@ -64,9 +30,9 @@ PDF::API2::Lite - lite pdf creation
 
 =head1 METHODS
 
-=head2 PDF::API2::Lite
+=over
 
-=item $pdf = PDF::API::Lite->new
+=item $pdf = PDF::API2::Lite->new
 
 =cut
 
@@ -663,62 +629,12 @@ sub print {
 
 __END__
 
+=back
+
 =head1 AUTHOR
 
 alfred reibenschuh
 
-=head1 HISTORY
-
-    $Log: Lite.pm,v $
-    Revision 2.1  2007/05/08 18:32:09  areibens
-    renamed compress to compressFlate
-
-    Revision 2.0  2005/11/16 02:16:00  areibens
-    revision workaround for SF cvs import not to screw up CPAN
-
-    Revision 1.2  2005/11/16 01:27:48  areibens
-    genesis2
-
-    Revision 1.1  2005/11/16 01:19:24  areibens
-    genesis
-
-    Revision 1.12  2005/06/17 19:43:47  fredo
-    fixed CPAN modulefile versioning (again)
-
-    Revision 1.11  2005/06/17 18:53:33  fredo
-    fixed CPAN modulefile versioning (dislikes cvs)
-
-    Revision 1.10  2005/03/14 22:01:05  fredo
-    upd 2005
-
-    Revision 1.9  2005/02/28 18:00:06  fredo
-    removed color method since businesscolor is not available anymore in PDF::API2
-
-    Revision 1.8  2004/12/16 00:30:51  fredo
-    added no warn for recursion
-
-    Revision 1.7  2004/06/15 09:11:38  fredo
-    removed cr+lf
-
-    Revision 1.6  2004/06/07 19:44:12  fredo
-    cleaned out cr+lf for lf
-
-    Revision 1.5  2004/05/21 15:04:43  fredo
-    fixed NAME pod bug for cpan indexer
-
-    Revision 1.4  2003/12/08 13:05:19  Administrator
-    corrected to proper licencing statement
-
-    Revision 1.3  2003/11/30 17:11:55  Administrator
-    merged into default
-
-    Revision 1.2.2.1  2003/11/30 16:56:21  Administrator
-    merged into default
-
-    Revision 1.2  2003/11/30 11:32:56  Administrator
-    added CVS id/log
-
-
 =cut
 
 
