@@ -1,56 +1,24 @@
-#=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
-#
-#=======================================================================
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2 of the License, or (at your option) any later version.
-#
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the
-#   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-#   Boston, MA 02111-1307, USA.
-#
-#   $Id: BaseFont.pm,v 2.9 2007/10/16 20:08:19 areibens Exp $
-#
-#=======================================================================
 package PDF::API2::Resource::BaseFont;
 
-BEGIN {
+our $VERSION = '2.016';
 
-    use utf8;
-    use Encode qw(:all);
+use base 'PDF::API2::Resource';
 
-    use PDF::API2::Util;
-    use PDF::API2::Basic::PDF::Utils;
-    use PDF::API2::Resource;
-    use Compress::Zlib;
-    
-    use vars qw(@ISA $VERSION);
+use Compress::Zlib;
+use Encode qw(:all);
+use PDF::API2::Basic::PDF::Utils;
+use PDF::API2::Util;
 
-    @ISA = qw( PDF::API2::Resource );
-
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.9 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/10/16 20:08:19 $
-
-}
 no warnings qw[ deprecated recursion uninitialized ];
 
+=head1 NAME
+
+PDF::API2::Resource::BaseFont
+
+=head1 METHODS
+
+=over
+
 =item $font = PDF::API2::Resource::BaseFont->new $pdf, $name
 
 Returns a font resource object.
@@ -196,7 +164,7 @@ sub tounicodemap {
 
 =head1 FONT-MANAGEMENT RELATED METHODS
 
-=over 4
+=over
 
 =item $name = $font->fontname()
 
@@ -250,7 +218,7 @@ sub iscff { return( $_[0]->data->{iscff} ); }
 
 =head1 TYPOGRAPHY RELATED METHODS
 
-=over 4
+=over
 
 =item ($llx, $lly, $urx, $ury) = $font->fontbbox()
 
@@ -693,7 +661,7 @@ sub width_array {
 
 =head1 STRING METHODS
 
-=over 4
+=over
 
 =item $utf8string = $font->utfByStr $string
 
@@ -826,100 +794,6 @@ __END__
 
 =head1 AUTHOR
 
-alfred reibenschuh.
-
-=head1 HISTORY
-
-    $Log: BaseFont.pm,v $
-    Revision 2.9  2007/10/16 20:08:19  areibens
-    changed undef safeguards for wx* methods
-
-    Revision 2.8  2007/10/10 06:18:15  areibens
-    fixed noisy undef handling of isvirtual
-
-    Revision 2.7  2007/04/07 10:25:46  areibens
-    fixed fix for wxByGlyph not honoring cidfont width arrays
-
-    Revision 2.6  2007/04/07 09:51:16  areibens
-    fix for wxByGlyph not honoring cidfont width arrays
-
-    Revision 2.5  2007/01/04 16:33:20  areibens
-    fix acro 8 fix
-
-    Revision 2.4  2007/01/04 16:02:28  areibens
-    applied untested fix for acrobat 8 "<ident> TJ" bug
-
-    Revision 2.3  2006/08/14 18:11:47  areibens
-    fixed wxByGlyph
-
-    Revision 2.2  2006/06/14 16:57:52  areibens
-    fixed ToUnicode cmap greneration to use actual encoden rather than the default
-
-    Revision 2.1  2006/06/14 16:53:00  areibens
-    fixed unicode lookup to use actual encoding rather than default
-
-    Revision 2.0  2005/11/16 02:16:04  areibens
-    revision workaround for SF cvs import not to screw up CPAN
-
-    Revision 1.2  2005/11/16 01:27:48  areibens
-    genesis2
-
-    Revision 1.1  2005/11/16 01:19:25  areibens
-    genesis
-
-    Revision 1.18  2005/10/19 19:06:27  fredo
-    added handling of kerning
-
-    Revision 1.17  2005/06/17 19:44:03  fredo
-    fixed CPAN modulefile versioning (again)
-
-    Revision 1.16  2005/06/17 18:53:34  fredo
-    fixed CPAN modulefile versioning (dislikes cvs)
-
-    Revision 1.15  2005/03/14 22:01:06  fredo
-    upd 2005
-
-    Revision 1.14  2005/01/21 10:03:09  fredo
-    added object saver for cmap
-
-    Revision 1.13  2004/12/16 00:30:53  fredo
-    added no warn for recursion
-
-    Revision 1.12  2004/11/24 20:10:55  fredo
-    added virtual font handling
-
-    Revision 1.11  2004/11/22 02:05:32  fredo
-    added pdf-1.5 font param specs
-
-    Revision 1.10  2004/10/26 14:41:37  fredo
-    added panose identification style entry
-
-    Revision 1.9  2004/10/17 03:55:00  fredo
-    simplified ToUnicode associated CMap for single-byte fonts
-
-    Revision 1.8  2004/10/17 03:47:36  fredo
-    fixed inclusion of ToUnicode compatible key and associated CMap
-
-    Revision 1.7  2004/06/15 09:14:41  fredo
-    removed cr+lf
-
-    Revision 1.6  2004/06/07 19:44:36  fredo
-    cleaned out cr+lf for lf
-
-    Revision 1.5  2004/04/20 09:47:34  fredo
-    fixed unicode to font-encoding-vector conversion
-
-    Revision 1.4  2003/12/08 13:05:32  Administrator
-    corrected to proper licencing statement
-
-    Revision 1.3  2003/11/30 17:28:54  Administrator
-    merged into default
-
-    Revision 1.2.2.1  2003/11/30 16:56:35  Administrator
-    merged into default
-
-    Revision 1.2  2003/11/30 11:44:49  Administrator
-    added CVS id/log
-
+Alfred Reibenschuh.
 
 =cut
