@@ -1,58 +1,24 @@
-#=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
-#
-#=======================================================================
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2 of the License, or (at your option) any later version.
-#
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the
-#   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-#   Boston, MA 02111-1307, USA.
-#
-#   $Id: CIDFont.pm,v 2.3 2007/03/17 20:38:50 areibens Exp $
-#
-#=======================================================================
 package PDF::API2::Resource::CIDFont;
 
-BEGIN 
-{
+our $VERSION = '2.016';
 
-    use utf8;
-    use Encode qw(:all);
+use base 'PDF::API2::Resource::BaseFont';
 
-    use PDF::API2::Util;
-    use PDF::API2::Basic::PDF::Utils;
-    use PDF::API2::Resource::BaseFont;
+use Encode qw(:all);
 
-    use POSIX;
-
-    use vars qw(@ISA $VERSION);
-
-    @ISA = qw( PDF::API2::Resource::BaseFont );
-
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.3 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/03/17 20:38:50 $
-}
+use PDF::API2::Basic::PDF::Utils;
+use PDF::API2::Util;
 
 no warnings qw[ deprecated recursion uninitialized ];
 
+=head1 NAME
+
+PDF::API2::Resource::CIDFont
+
+=head1 METHODS
+
+=over
+
 =item $font = PDF::API2::Resource::CIDFont->new $pdf, $name
 
 Returns a cid-font object. base class form all CID based fonts.
@@ -399,76 +365,11 @@ sub outobjdeep
 
 __END__
 
+=back
+
 =head1 AUTHOR
 
 alfred reibenschuh
 
-=head1 HISTORY
-
-    $Log: CIDFont.pm,v $
-    Revision 2.3  2007/03/17 20:38:50  areibens
-    replaced IOString dep. with scalar IO.
-
-    Revision 2.2  2007/01/04 16:02:28  areibens
-    applied untested fix for acrobat 8 "<ident> TJ" bug
-
-    Revision 2.1  2006/06/19 19:22:07  areibens
-    removed dup sub
-
-    Revision 2.0  2005/11/16 02:16:04  areibens
-    revision workaround for SF cvs import not to screw up CPAN
-
-    Revision 1.2  2005/11/16 01:27:48  areibens
-    genesis2
-
-    Revision 1.1  2005/11/16 01:19:25  areibens
-    genesis
-
-    Revision 1.15  2005/10/20 21:05:05  fredo
-    added handling of optional kerning
-
-    Revision 1.14  2005/06/17 19:44:03  fredo
-    fixed CPAN modulefile versioning (again)
-
-    Revision 1.13  2005/06/17 18:53:34  fredo
-    fixed CPAN modulefile versioning (dislikes cvs)
-
-    Revision 1.12  2005/03/14 22:01:06  fredo
-    upd 2005
-
-    Revision 1.11  2004/12/16 00:30:53  fredo
-    added no warn for recursion
-
-    Revision 1.10  2004/11/24 20:10:55  fredo
-    added virtual font handling
-
-    Revision 1.9  2004/11/22 21:07:55  fredo
-    fixed multibyte-encoding support to work consistently acress cjk/ttf/otf
-
-    Revision 1.8  2004/11/21 02:57:53  fredo
-    cosmetic change
-
-    Revision 1.7  2004/10/26 14:42:49  fredo
-    added alternative glyph-width storage/retrieval
-
-    Revision 1.6  2004/06/15 09:14:41  fredo
-    removed cr+lf
-
-    Revision 1.5  2004/06/07 19:44:36  fredo
-    cleaned out cr+lf for lf
-
-    Revision 1.4  2003/12/08 13:05:33  Administrator
-    corrected to proper licencing statement
-
-    Revision 1.3  2003/11/30 17:28:54  Administrator
-    merged into default
-
-    Revision 1.2.2.1  2003/11/30 16:56:35  Administrator
-    merged into default
-
-    Revision 1.2  2003/11/30 11:44:49  Administrator
-    added CVS id/log
-
-
 =cut
 
