@@ -1,61 +1,27 @@
-#=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
-#
-#=======================================================================
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2 of the License, or (at your option) any later version.
-#
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the
-#   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-#   Boston, MA 02111-1307, USA.
-#
-#   $Id: CJKFont.pm,v 2.1 2007/03/17 20:38:51 areibens Exp $
-#
-#=======================================================================
 package PDF::API2::Resource::CIDFont::CJKFont;
 
-BEGIN {
+our $VERSION = '2.016';
 
-    use utf8;
-    use Encode qw(:all);
+use base 'PDF::API2::Resource::CIDFont';
 
-    use PDF::API2::Util;
-    use PDF::API2::Basic::PDF::Utils;
-    use PDF::API2::Resource::CIDFont;
+use PDF::API2::Util;
+use PDF::API2::Basic::PDF::Utils;
 
-    use PDF::API2::Basic::TTF::Font;
-
-    use POSIX;
-
-    use vars qw( @ISA $fonts $cmap $alias $subs $VERSION );
-
-    @ISA = qw( PDF::API2::Resource::CIDFont );
-
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/03/17 20:38:51 $
-
-    $fonts = { };
-    $cmap = { };
-}
 no warnings qw[ deprecated recursion uninitialized ];
 
+our $fonts = {};
+our $cmap  = {};
+our $alias;
+our $subs;
+
+=head1 NAME
+
+PDF::API2::Resource::CIDFont::CJKFont
+
+=head1 METHODS
+
+=over
+
 =item $font = PDF::API2::Resource::CIDFont::CJKFont->new $pdf, $cjkname, %options
 
 Returns a cjk-font object.
@@ -99,7 +65,7 @@ sub _look_for_font {
         return({%{$data}})
     }
 
-    eval "require PDF::API2::Resource::CIDFont::CJKFont::$fname; ";
+    eval "require 'PDF/API2/Resource/CIDFont/CJKFont/$fname.data'";
     unless($@){
         return({%{$fonts->{$fname}}});
     } else {
@@ -374,79 +340,11 @@ BEGIN {
 
 __END__
 
+=back
+
 =head1 AUTHOR
 
-alfred reibenschuh
-
-=head1 HISTORY
-
-    $Log: CJKFont.pm,v $
-    Revision 2.1  2007/03/17 20:38:51  areibens
-    replaced IOString dep. with scalar IO.
-
-    Revision 2.0  2005/11/16 02:16:04  areibens
-    revision workaround for SF cvs import not to screw up CPAN
-
-    Revision 1.2  2005/11/16 01:27:48  areibens
-    genesis2
-
-    Revision 1.1  2005/11/16 01:19:25  areibens
-    genesis
-
-    Revision 1.17  2005/06/17 19:44:03  fredo
-    fixed CPAN modulefile versioning (again)
-
-    Revision 1.16  2005/06/17 18:53:34  fredo
-    fixed CPAN modulefile versioning (dislikes cvs)
-
-    Revision 1.15  2003/04/09 11:13:12  fredo
-    added/fixed proper alias/substitutions
-
-    Revision 1.14  2005/03/14 22:01:07  fredo
-    upd 2005
-
-    Revision 1.13  2004/12/16 00:30:53  fredo
-    added no warn for recursion
-
-    Revision 1.12  2004/11/25 15:07:21  fredo
-    fixed prototype warning
-
-    Revision 1.11  2004/11/22 21:07:55  fredo
-    fixed multibyte-encoding support to work consistently acress cjk/ttf/otf
-
-    Revision 1.10  2004/11/22 02:04:27  fredo
-    added missing substitutes
-
-    Revision 1.9  2004/11/22 01:03:24  fredo
-    fixed supplement set, added substitute handling
-
-    Revision 1.8  2004/11/21 02:58:51  fredo
-    fixed multibyte encoding issues
-
-    Revision 1.7  2004/10/26 14:43:25  fredo
-    added alternative glyph-width storage/retrieval
-
-    Revision 1.6  2004/06/15 09:14:42  fredo
-    removed cr+lf
-
-    Revision 1.5  2004/06/07 19:44:36  fredo
-    cleaned out cr+lf for lf
-
-    Revision 1.4  2004/02/24 00:08:54  fredo
-    added utf8 fallback for encoding
-
-    Revision 1.3  2003/12/08 13:05:33  Administrator
-    corrected to proper licencing statement
-
-    Revision 1.2  2003/11/30 17:30:40  Administrator
-    merged into default
-
-    Revision 1.1.1.1.2.2  2003/11/30 16:56:36  Administrator
-    merged into default
-
-    Revision 1.1.1.1.2.1  2003/11/30 14:13:33  Administrator
-    added CVS id/log
-
+Alfred Reibenschuh
 
 =cut
 
