@@ -1,40 +1,11 @@
-#=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
-#
-#=======================================================================
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2 of the License, or (at your option) any later version.
-#
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the
-#   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-#   Boston, MA 02111-1307, USA.
-#
-#   $Id: timesbold.pm,v 1.5 2004/06/15 09:14:53 fredo Exp $
-#
-#=======================================================================
+package PDF::API2::Resource::Font::CoreFont::timesbold;
 
-$fonts->{timesbold}= {
+our $VERSION = '2.016';
+
+$FONTDATA = {
     'fontname' => 'Times-Bold',
     'type' => 'Type1',
-    'apiname' => 'Ti2',
+    'apiname' => 'TiBo',
     'ascender' => '683',
     'capheight' => '676',
     'descender' => '-217',
@@ -540,34 +511,3 @@ $fonts->{timesbold}= {
         'fl' => '556',                           # U+0xFB02
     }, # HORIZ. WIDTH TABLE
 };
-
-
-__END__
-
-=head1 AUTHOR
-
-alfred reibenschuh
-
-=head1 HISTORY
-
-    $Log: timesbold.pm,v $
-    Revision 1.5  2004/06/15 09:14:53  fredo
-    removed cr+lf
-
-    Revision 1.4  2004/06/07 19:44:43  fredo
-    cleaned out cr+lf for lf
-
-    Revision 1.3  2003/12/08 13:06:05  Administrator
-    corrected to proper licencing statement
-
-    Revision 1.2  2003/11/30 17:32:49  Administrator
-    merged into default
-
-    Revision 1.1.1.1.2.2  2003/11/30 16:57:06  Administrator
-    merged into default
-
-    Revision 1.1.1.1.2.1  2003/11/30 15:52:22  Administrator
-    added CVS id/log
-
-
-=cut
