@@ -1,57 +1,14 @@
-#=======================================================================
-#    ____  ____  _____              _    ____ ___   ____
-#   |  _ \|  _ \|  ___|  _   _     / \  |  _ \_ _| |___ \
-#   | |_) | | | | |_    (_) (_)   / _ \ | |_) | |    __) |
-#   |  __/| |_| |  _|    _   _   / ___ \|  __/| |   / __/
-#   |_|   |____/|_|     (_) (_) /_/   \_\_|  |___| |_____|
-#
-#   A Perl Module Chain to faciliate the Creation and Modification
-#   of High-Quality "Portable Document Format (PDF)" Files.
-#
-#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
-#
-#=======================================================================
-#
-#   This library is free software; you can redistribute it and/or
-#   modify it under the terms of the GNU Lesser General Public
-#   License as published by the Free Software Foundation; either
-#   version 2 of the License, or (at your option) any later version.
-#
-#   This library is distributed in the hope that it will be useful,
-#   but WITHOUT ANY WARRANTY; without even the implied warranty of
-#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-#   Lesser General Public License for more details.
-#
-#   You should have received a copy of the GNU Lesser General Public
-#   License along with this library; if not, write to the
-#   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-#   Boston, MA 02111-1307, USA.
-#
-#   $Id: PNM.pm,v 2.1 2007/05/24 19:29:46 areibens Exp $
-#
-#=======================================================================
 package PDF::API2::Resource::XObject::Image::PNM;
 
-BEGIN {
+our $VERSION = '2.016';
 
-    use PDF::API2::Util;
-    use PDF::API2::Basic::PDF::Utils;
-    use PDF::API2::Resource::XObject::Image;
+use base 'PDF::API2::Resource::XObject::Image';
 
-    use POSIX;
+use PDF::API2::Util;
+use PDF::API2::Basic::PDF::Utils;
 
-    use vars qw(@ISA $VERSION);
-    @ISA = qw( PDF::API2::Resource::XObject::Image );
-    ( $VERSION ) = sprintf '%i.%03i', split(/\./,('$Revision: 2.1 $' =~ /Revision: (\S+)\s/)[0]); # $Date: 2007/05/24 19:29:46 $
-}
 no warnings qw[ deprecated recursion uninitialized ];
 
-=item $res = PDF::API2::Resource::XObject::Image::PNM->new $pdf, $file [, $name]
-
-Returns a pnm-image object.
-
-=cut
-
 sub new {
     my ($class,$pdf,$file,$name) = @_;
     my $self;
@@ -69,13 +26,6 @@ sub new {
     return($self);
 }
 
-=item $res = PDF::API2::Resource::XObject::Image::PNM->new_api $api, $file [, $name]
-
-Returns a pnm-image object. This method is different from 'new' that
-it needs an PDF::API2-object rather than a Text::PDF::File-object.
-
-=cut
-
 sub new_api {
     my ($class,$api,@opts)=@_;
 
@@ -231,61 +181,6 @@ sub read_pnm {
 
 __END__
 
-=head1 AUTHOR
-
-alfred reibenschuh
-
-=head1 HISTORY
-
-    $Log: PNM.pm,v $
-    Revision 2.1  2007/05/24 19:29:46  areibens
-    fixed pnm bitmap decoding
-
-    Revision 2.0  2005/11/16 02:18:23  areibens
-    revision workaround for SF cvs import not to screw up CPAN
-
-    Revision 1.2  2005/11/16 01:27:50  areibens
-    genesis2
-
-    Revision 1.1  2005/11/16 01:19:27  areibens
-    genesis
-
-    Revision 1.10  2005/06/17 19:44:04  fredo
-    fixed CPAN modulefile versioning (again)
-
-    Revision 1.9  2005/06/17 18:53:35  fredo
-    fixed CPAN modulefile versioning (dislikes cvs)
-
-    Revision 1.8  2005/03/14 22:01:31  fredo
-    upd 2005
-
-    Revision 1.7  2004/12/16 00:30:55  fredo
-    added no warn for recursion
-
-    Revision 1.6  2004/07/24 23:38:47  fredo
-    added new headerparser and simplified loading
-
-    Revision 1.5  2004/06/15 09:14:54  fredo
-    removed cr+lf
-
-    Revision 1.4  2004/06/07 19:44:44  fredo
-    cleaned out cr+lf for lf
-
-    Revision 1.3  2003/12/08 13:06:11  Administrator
-    corrected to proper licencing statement
-
-    Revision 1.2  2003/11/30 17:37:17  Administrator
-    merged into default
-
-    Revision 1.1.1.1.2.2  2003/11/30 16:57:10  Administrator
-    merged into default
-
-    Revision 1.1.1.1.2.1  2003/11/30 16:00:42  Administrator
-    added CVS id/log
-
-
-=cut
-
 pam(5) pam(5)
 NAME
 pam - portable arbitrary map file format
@@ -646,4 +541,4 @@ pi1toppm(1), picttoppm(1), pjtoppm(1), qrttoppm(1), rawtoppm(1), rgb3toppm(1), s
 1), ppmdither(1), ppmforge(1), ppmhist(1), ppmmake(1), ppmpat(1), ppmquant(1), ppmquantall(
 1), ppmrelief(1), pnm(5), pgm(5), pbm(5)
 AUTHOR
-Copyright (C) 1989, 1991 by Jef Poskanzer.
\ No newline at end of file
+Copyright (C) 1989, 1991 by Jef Poskanzer.
